--[[
--
-- Big Wigs Strategy Module for Loatheb in Naxxramas.
--
-- Adds warning messages, whispers and raid icons for the groups that are next in line to get Spore
--
--	visit us at http://www.caelum.ws
--]]

------------------------------
--      Are you local?      --
------------------------------

local myname = "Loatheb Tactical"
local L = AceLibrary("AceLocale-2.2"):new("BigWigs"..myname)
local boss = AceLibrary("Babble-Boss-2.2")["Loatheb"]

----------------------------
--      Localization      --
----------------------------

L:RegisterTranslations("enUS", function() return {
	cmd = "BigWigsLoathebTactical",
	
	spore_cmd = "spore",
	spore_name = "Do NOT warn groups to get spore",
	spore_desc = "When checked does NOT warn groups to get spore over raidwarn, wispers and by placing icons",
	
	revsporeseq_cmd = "revsporeseq",
	revsporeseq_name = "Reverses group spore sequence",
	revsporeseq_desc = "When checked counts from group 1 to 8, instead of from group 8 to 1",

	skipsporegroup_cmd = "skipsporegroup",
	skipsporegroup_name = "Skips spore group 1",
	skipsporegroup_desc = "When checked skips group 1 in spore group list",
	
	spore_trigger = "Loatheb casts Summon Spore.",
	doomtrigger = "afflicted by Inevitable Doom.",
	
	group_spore_warn = "Group %s get your spore !",
	whisper_spore_warn = "Get your spore now !",
	
	consumable_cmd = "consumable",
	consumable_name = "Do NOT warn raid to use consumables",
	consumable_desc = "When check does NOT warn raid to use consambles over raidwarn",
	
	shadowpot = "-- Drink Shadow Protection Potion ! --",
	bandage = "-- Use your bandages ! --",
	wrtorhs = "-- Healthstone or Whipper Root Tuber ! --",
	shadowpotandbandage = "-- Drink Shadow Protection Potion and Bandage ! --",
	noconsumable = "-- No Consumable at this time ! --"

} end )

-- timing -------------------2:10-------------2:40------------3:10---------3:40--------------4:10---------------4:40--------------5:10-----------5:25-------------5:40
-- after 5 minutes doom comes every 15seconds
local consumableslist = {L["shadowpot"],L["noconsumable"],L["bandage"],L["wrtorhs"],L["shadowpotandbandage"],L["noconsumable"],L["bandage"],L["noconsumable"],L["wrtorhs"]}

----------------------------------
--      Module Declaration      --
----------------------------------

BigWigsLoathebTactical = BigWigs:NewModule(myname)
BigWigsLoathebTactical.synctoken = myname
BigWigsLoathebTactical.zonename = AceLibrary("Babble-Zone-2.2")["Naxxramas"]
BigWigsLoathebTactical.enabletrigger = { boss }
BigWigsLoathebTactical.toggleoptions = { "spore", "revsporeseq", "skipsporegroup", "consumable" }
BigWigsLoathebTactical.revision = tonumber(string.sub("$Rev: 17229 $", 12, -3))

------------------------------
--      Initialization      --
------------------------------

function BigWigsLoathebTactical:OnEnable()
	self.sporegroup = 8
	self.consumableseq = 1

	self:RegisterEvent("PLAYER_REGEN_ENABLED", "CheckForWipe")
	self:RegisterEvent("CHAT_MSG_COMBAT_HOSTILE_DEATH")
	
	self:RegisterEvent("CHAT_MSG_SPELL_CREATURE_VS_CREATURE_BUFF")
	
	self:RegisterEvent("BigWigs_RecvSync")
	self:TriggerEvent("BigWigs_ThrottleSync", "LoathebDoom2", 10)
	
	DEFAULT_CHAT_FRAME:AddMessage("Bigwigs Loatheb Tactical Module has been reset");	
end

------------------------------
--      Utility             --
------------------------------

function BigWigsLoathebTactical:BigWigs_RecvSync( sync, rest, nick )
	if sync == "LoathebDoom2" then		
		if not self.db.profile.consumable then
			self:ScheduleEvent("bwloathebconsumable", self.ConsumableWarning, 11, self)
		end			
	end
end

function BigWigsLoathebTactical:ConsumableWarning()
	if consumableslist[self.consumableseq] then
		-- Avoiding bossblock to make sure everyone gets the message about the potions
		SendChatMessage(consumableslist[self.consumableseq], "RAID_WARNING")		
		--self:TriggerEvent("BigWigs_Message", consumableslist[self.consumableseq], "Red")	
		self.consumableseq = self.consumableseq + 1
	end
end

function BigWigsLoathebTactical:GroupWarning()
	local raidicon = 1;
	
	-- If it's the first sporespawn and we reversed the sequence then start counting from group 1 instead of group 8
	if BigWigsLoatheb.sporeCount == 1 and self.db.profile.revsporeseq then
		self.sporegroup = 1
	end
	-- No need to avoid bossblock for spore warnings
	SendChatMessage(string.format( L["group_spore_warn"], self.sporegroup), "RAID_WARNING")	
	--self:TriggerEvent("BigWigs_Message", string.format( L["group_spore_warn"], self.sporegroup), "Red")
	
	for i = 1, GetNumRaidMembers(), 1 do
		name, _, subgroup, _, _, _, _, _ = GetRaidRosterInfo(i)
	
		if subgroup == self.sporegroup then			
			SetRaidTarget("raid" .. i, raidicon)
			self:TriggerEvent("BigWigs_SendTell", name, L["whisper_spore_warn"])
			raidicon = raidicon + 1
		end
	end	
end

function BigWigsLoathebTactical:GroupCountDown()
	local startgroup = 8
	local endgroup = 1	
	if self.db.profile.skipsporegroup then
		endgroup = 2
	end
	
	self.sporegroup = self.sporegroup - 1
	if self.sporegroup < endgroup then
		self.sporegroup = startgroup
	end
end

function BigWigsLoathebTactical:GroupCountUp()
	local startgroup = 1
	local endgroup = 8
	if self.db.profile.skipsporegroup then
		startgroup = 2
	end
	
	self.sporegroup = self.sporegroup + 1
	if self.sporegroup > endgroup then
		self.sporegroup = startgroup
	end
end
------------------------------
--      Event Handlers      --
------------------------------

function BigWigsLoathebTactical:CHAT_MSG_COMBAT_HOSTILE_DEATH(msg)
	if msg == string.format(UNITDIESOTHER, boss) then
		self.core:ToggleModuleActive(self, false)
	end
end

function BigWigsLoathebTactical:CHAT_MSG_SPELL_CREATURE_VS_CREATURE_BUFF(msg)
	if msg == L["spore_trigger"] then		
		if not self.db.profile.spore then
			self:GroupWarning()
			if self.db.profile.revsporeseq then
				self:GroupCountUp()
			else
				self:GroupCountDown()
			end
		end		
	end
end

